==> components-1.2.0.tgz: package/esm/Molecules/Tooltips/TooltipHost.js <==
function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _templateObject() {
  var data = _taggedTemplateLiteral(["\n  width: fit-content;\n  display: inline-flex;\n"]);

  _templateObject = function _templateObject() {
    return data;
  };

  return data;
}

function _taggedTemplateLiteral(strings, raw) { if (!raw) { raw = strings.slice(0); } return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

import React from 'react';
import PropTypes from 'prop-types';
import styled from 'styled-components';
import ReactTooltip from 'react-tooltip';
var Wrapper = styled.div(_templateObject());

var TooltipHost =
/*#__PURE__*/
function (_React$PureComponent) {
  _inherits(TooltipHost, _React$PureComponent);

  function TooltipHost() {
    _classCallCheck(this, TooltipHost);

    return _possibleConstructorReturn(this, _getPrototypeOf(TooltipHost).apply(this, arguments));
  }

  _createClass(TooltipHost, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      ReactTooltip.rebuild();
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props = this.props,
          tip = _this$props.tip,
          children = _this$props.children,
          id = _this$props.id;
      var dataTip = tip || [];
      return React.createElement(Wrapper, _extends({
        "data-for": id,
        "data-tip": dataTip
      }, this.props), children);
    }
  }]);

  return TooltipHost;
}(React.PureComponent);

TooltipHost.propTypes = {
  children: PropTypes.node.isRequired,
  id: PropTypes.string.isRequired,
  tip: PropTypes.string
};
export default TooltipHost;

==> components-2.0.10.tgz: package/esm/Molecules/Tooltips/TooltipHost.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _classCallCheck from "@babel/runtime/helpers/esm/classCallCheck";
import _createClass from "@babel/runtime/helpers/esm/createClass";
import _possibleConstructorReturn from "@babel/runtime/helpers/esm/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _inherits from "@babel/runtime/helpers/esm/inherits";
import React from 'react';
import PropTypes from 'prop-types';
import styled from 'styled-components';
import ReactTooltip from 'react-tooltip';
var Wrapper =
/*#__PURE__*/
styled.div.withConfig({
  componentId: "sc-8q376a-0"
})(["width:fit-content;display:inline-flex;"]);

var TooltipHost =
/*#__PURE__*/
function (_React$PureComponent) {
  _inherits(TooltipHost, _React$PureComponent);

  function TooltipHost() {
    _classCallCheck(this, TooltipHost);

    return _possibleConstructorReturn(this, _getPrototypeOf(TooltipHost).apply(this, arguments));
  }

  _createClass(TooltipHost, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      ReactTooltip.rebuild();
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props = this.props,
          tip = _this$props.tip,
          children = _this$props.children,
          id = _this$props.id;
      var dataTip = tip || [];
      return React.createElement(Wrapper, _extends({
        "data-for": id,
        "data-tip": dataTip
      }, this.props), children);
    }
  }]);

  return TooltipHost;
}(React.PureComponent);

TooltipHost.propTypes = process.env.NODE_ENV !== "production" ? {
  children: PropTypes.node.isRequired,
  id: PropTypes.string.isRequired,
  tip: PropTypes.string
} : {};
export default TooltipHost;
